import common_pb2 as _common_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class ProcessOptions(_message.Message):
    __slots__ = ["streaming", "llm_name", "input_token_limit", "output_token_limit", "timeout"]
    STREAMING_FIELD_NUMBER: _ClassVar[int]
    LLM_NAME_FIELD_NUMBER: _ClassVar[int]
    INPUT_TOKEN_LIMIT_FIELD_NUMBER: _ClassVar[int]
    OUTPUT_TOKEN_LIMIT_FIELD_NUMBER: _ClassVar[int]
    TIMEOUT_FIELD_NUMBER: _ClassVar[int]
    streaming: bool
    llm_name: str
    input_token_limit: int
    output_token_limit: int
    timeout: int
    def __init__(self, streaming: bool = ..., llm_name: _Optional[str] = ..., input_token_limit: _Optional[int] = ..., output_token_limit: _Optional[int] = ..., timeout: _Optional[int] = ...) -> None: ...

class ProcessTaskRequest(_message.Message):
    __slots__ = ["input_files", "task", "context_id", "options"]
    INPUT_FILES_FIELD_NUMBER: _ClassVar[int]
    TASK_FIELD_NUMBER: _ClassVar[int]
    CONTEXT_ID_FIELD_NUMBER: _ClassVar[int]
    OPTIONS_FIELD_NUMBER: _ClassVar[int]
    input_files: _containers.RepeatedScalarFieldContainer[str]
    task: str
    context_id: str
    options: ProcessOptions
    def __init__(self, input_files: _Optional[_Iterable[str]] = ..., task: _Optional[str] = ..., context_id: _Optional[str] = ..., options: _Optional[_Union[ProcessOptions, _Mapping]] = ...) -> None: ...

class OnStepActionStart(_message.Message):
    __slots__ = ["input", "tool"]
    INPUT_FIELD_NUMBER: _ClassVar[int]
    TOOL_FIELD_NUMBER: _ClassVar[int]
    input: str
    tool: str
    def __init__(self, input: _Optional[str] = ..., tool: _Optional[str] = ...) -> None: ...

class OnStepActionEnd(_message.Message):
    __slots__ = ["output", "output_files", "has_error"]
    OUTPUT_FIELD_NUMBER: _ClassVar[int]
    OUTPUT_FILES_FIELD_NUMBER: _ClassVar[int]
    HAS_ERROR_FIELD_NUMBER: _ClassVar[int]
    output: str
    output_files: _containers.RepeatedScalarFieldContainer[str]
    has_error: bool
    def __init__(self, output: _Optional[str] = ..., output_files: _Optional[_Iterable[str]] = ..., has_error: bool = ...) -> None: ...

class FinalAnswer(_message.Message):
    __slots__ = ["answer"]
    ANSWER_FIELD_NUMBER: _ClassVar[int]
    answer: str
    def __init__(self, answer: _Optional[str] = ...) -> None: ...

class ContextState(_message.Message):
    __slots__ = ["output_token_count", "input_token_count", "llm_name", "total_duration", "llm_response_duration"]
    OUTPUT_TOKEN_COUNT_FIELD_NUMBER: _ClassVar[int]
    INPUT_TOKEN_COUNT_FIELD_NUMBER: _ClassVar[int]
    LLM_NAME_FIELD_NUMBER: _ClassVar[int]
    TOTAL_DURATION_FIELD_NUMBER: _ClassVar[int]
    LLM_RESPONSE_DURATION_FIELD_NUMBER: _ClassVar[int]
    output_token_count: int
    input_token_count: int
    llm_name: str
    total_duration: int
    llm_response_duration: int
    def __init__(self, output_token_count: _Optional[int] = ..., input_token_count: _Optional[int] = ..., llm_name: _Optional[str] = ..., total_duration: _Optional[int] = ..., llm_response_duration: _Optional[int] = ...) -> None: ...

class TypingContent(_message.Message):
    __slots__ = ["content", "language"]
    CONTENT_FIELD_NUMBER: _ClassVar[int]
    LANGUAGE_FIELD_NUMBER: _ClassVar[int]
    content: str
    language: str
    def __init__(self, content: _Optional[str] = ..., language: _Optional[str] = ...) -> None: ...

class TaskResponse(_message.Message):
    __slots__ = ["state", "response_type", "on_step_action_start", "on_step_action_end", "final_answer", "console_stdout", "console_stderr", "error_msg", "typing_content"]
    class ResponseType(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = []
        OnStepActionStart: _ClassVar[TaskResponse.ResponseType]
        OnStepActionStreamStdout: _ClassVar[TaskResponse.ResponseType]
        OnStepActionStreamStderr: _ClassVar[TaskResponse.ResponseType]
        OnStepActionEnd: _ClassVar[TaskResponse.ResponseType]
        OnFinalAnswer: _ClassVar[TaskResponse.ResponseType]
        OnModelTypeText: _ClassVar[TaskResponse.ResponseType]
        OnModelTypeCode: _ClassVar[TaskResponse.ResponseType]
        OnModelOutputError: _ClassVar[TaskResponse.ResponseType]
        OnInputTokenLimitExceed: _ClassVar[TaskResponse.ResponseType]
        OnOutputTokenLimitExceed: _ClassVar[TaskResponse.ResponseType]
        OnSystemError: _ClassVar[TaskResponse.ResponseType]
    OnStepActionStart: TaskResponse.ResponseType
    OnStepActionStreamStdout: TaskResponse.ResponseType
    OnStepActionStreamStderr: TaskResponse.ResponseType
    OnStepActionEnd: TaskResponse.ResponseType
    OnFinalAnswer: TaskResponse.ResponseType
    OnModelTypeText: TaskResponse.ResponseType
    OnModelTypeCode: TaskResponse.ResponseType
    OnModelOutputError: TaskResponse.ResponseType
    OnInputTokenLimitExceed: TaskResponse.ResponseType
    OnOutputTokenLimitExceed: TaskResponse.ResponseType
    OnSystemError: TaskResponse.ResponseType
    STATE_FIELD_NUMBER: _ClassVar[int]
    RESPONSE_TYPE_FIELD_NUMBER: _ClassVar[int]
    ON_STEP_ACTION_START_FIELD_NUMBER: _ClassVar[int]
    ON_STEP_ACTION_END_FIELD_NUMBER: _ClassVar[int]
    FINAL_ANSWER_FIELD_NUMBER: _ClassVar[int]
    CONSOLE_STDOUT_FIELD_NUMBER: _ClassVar[int]
    CONSOLE_STDERR_FIELD_NUMBER: _ClassVar[int]
    ERROR_MSG_FIELD_NUMBER: _ClassVar[int]
    TYPING_CONTENT_FIELD_NUMBER: _ClassVar[int]
    state: ContextState
    response_type: TaskResponse.ResponseType
    on_step_action_start: OnStepActionStart
    on_step_action_end: OnStepActionEnd
    final_answer: FinalAnswer
    console_stdout: str
    console_stderr: str
    error_msg: str
    typing_content: TypingContent
    def __init__(self, state: _Optional[_Union[ContextState, _Mapping]] = ..., response_type: _Optional[_Union[TaskResponse.ResponseType, str]] = ..., on_step_action_start: _Optional[_Union[OnStepActionStart, _Mapping]] = ..., on_step_action_end: _Optional[_Union[OnStepActionEnd, _Mapping]] = ..., final_answer: _Optional[_Union[FinalAnswer, _Mapping]] = ..., console_stdout: _Optional[str] = ..., console_stderr: _Optional[str] = ..., error_msg: _Optional[str] = ..., typing_content: _Optional[_Union[TypingContent, _Mapping]] = ...) -> None: ...

class AddKernelRequest(_message.Message):
    __slots__ = ["endpoint", "key"]
    ENDPOINT_FIELD_NUMBER: _ClassVar[int]
    KEY_FIELD_NUMBER: _ClassVar[int]
    endpoint: str
    key: str
    def __init__(self, endpoint: _Optional[str] = ..., key: _Optional[str] = ...) -> None: ...

class AddKernelResponse(_message.Message):
    __slots__ = ["code", "msg"]
    CODE_FIELD_NUMBER: _ClassVar[int]
    MSG_FIELD_NUMBER: _ClassVar[int]
    code: int
    msg: str
    def __init__(self, code: _Optional[int] = ..., msg: _Optional[str] = ...) -> None: ...

class AssembleAppRequest(_message.Message):
    __slots__ = ["name", "language", "code", "saved_filenames", "desc"]
    NAME_FIELD_NUMBER: _ClassVar[int]
    LANGUAGE_FIELD_NUMBER: _ClassVar[int]
    CODE_FIELD_NUMBER: _ClassVar[int]
    SAVED_FILENAMES_FIELD_NUMBER: _ClassVar[int]
    DESC_FIELD_NUMBER: _ClassVar[int]
    name: str
    language: str
    code: str
    saved_filenames: _containers.RepeatedScalarFieldContainer[str]
    desc: str
    def __init__(self, name: _Optional[str] = ..., language: _Optional[str] = ..., code: _Optional[str] = ..., saved_filenames: _Optional[_Iterable[str]] = ..., desc: _Optional[str] = ...) -> None: ...

class AssembleAppResponse(_message.Message):
    __slots__ = ["code", "msg"]
    CODE_FIELD_NUMBER: _ClassVar[int]
    MSG_FIELD_NUMBER: _ClassVar[int]
    code: int
    msg: str
    def __init__(self, code: _Optional[int] = ..., msg: _Optional[str] = ...) -> None: ...

class RunAppRequest(_message.Message):
    __slots__ = ["name"]
    NAME_FIELD_NUMBER: _ClassVar[int]
    name: str
    def __init__(self, name: _Optional[str] = ...) -> None: ...

class AppInfo(_message.Message):
    __slots__ = ["name", "language", "ctime", "desc"]
    NAME_FIELD_NUMBER: _ClassVar[int]
    LANGUAGE_FIELD_NUMBER: _ClassVar[int]
    CTIME_FIELD_NUMBER: _ClassVar[int]
    DESC_FIELD_NUMBER: _ClassVar[int]
    name: str
    language: str
    ctime: int
    desc: str
    def __init__(self, name: _Optional[str] = ..., language: _Optional[str] = ..., ctime: _Optional[int] = ..., desc: _Optional[str] = ...) -> None: ...

class QueryAppsRequest(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class QueryAppsResponse(_message.Message):
    __slots__ = ["apps"]
    APPS_FIELD_NUMBER: _ClassVar[int]
    apps: _containers.RepeatedCompositeFieldContainer[AppInfo]
    def __init__(self, apps: _Optional[_Iterable[_Union[AppInfo, _Mapping]]] = ...) -> None: ...

class PingRequest(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class PongResponse(_message.Message):
    __slots__ = ["code", "msg"]
    CODE_FIELD_NUMBER: _ClassVar[int]
    MSG_FIELD_NUMBER: _ClassVar[int]
    code: int
    msg: str
    def __init__(self, code: _Optional[int] = ..., msg: _Optional[str] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: agent_server.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import common_pb2 as common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x12\x61gent_server.proto\x12\x13octopus_agent_proto\x1a\x0c\x63ommon.proto\"}\n\x0eProcessOptions\x12\x11\n\tstreaming\x18\x01 \x01(\x08\x12\x10\n\x08llm_name\x18\x02 \x01(\t\x12\x19\n\x11input_token_limit\x18\x03 \x01(\x05\x12\x1a\n\x12output_token_limit\x18\x04 \x01(\x05\x12\x0f\n\x07timeout\x18\x05 \x01(\x05\"\x81\x01\n\x12ProcessTaskRequest\x12\x13\n\x0binput_files\x18\x01 \x03(\t\x12\x0c\n\x04task\x18\x02 \x01(\t\x12\x12\n\ncontext_id\x18\x03 \x01(\t\x12\x34\n\x07options\x18\x04 \x01(\x0b\x32#.octopus_agent_proto.ProcessOptions\"0\n\x11OnStepActionStart\x12\r\n\x05input\x18\x01 \x01(\t\x12\x0c\n\x04tool\x18\x02 \x01(\t\"J\n\x0fOnStepActionEnd\x12\x0e\n\x06output\x18\x01 \x01(\t\x12\x14\n\x0coutput_files\x18\x02 \x03(\t\x12\x11\n\thas_error\x18\x03 \x01(\x08\"\x1d\n\x0b\x46inalAnswer\x12\x0e\n\x06\x61nswer\x18\x01 \x01(\t\"\x8e\x01\n\x0c\x43ontextState\x12\x1a\n\x12output_token_count\x18\x01 \x01(\x05\x12\x19\n\x11input_token_count\x18\x02 \x01(\x05\x12\x10\n\x08llm_name\x18\x03 \x01(\t\x12\x16\n\x0etotal_duration\x18\x04 \x01(\x05\x12\x1d\n\x15llm_response_duration\x18\x05 \x01(\x05\"2\n\rTypingContent\x12\x0f\n\x07\x63ontent\x18\x01 \x01(\t\x12\x10\n\x08language\x18\x02 \x01(\t\"\xf8\x05\n\x0cTaskResponse\x12\x30\n\x05state\x18\x01 \x01(\x0b\x32!.octopus_agent_proto.ContextState\x12\x45\n\rresponse_type\x18\x04 \x01(\x0e\x32..octopus_agent_proto.TaskResponse.ResponseType\x12\x46\n\x14on_step_action_start\x18\x05 \x01(\x0b\x32&.octopus_agent_proto.OnStepActionStartH\x00\x12\x42\n\x12on_step_action_end\x18\x06 \x01(\x0b\x32$.octopus_agent_proto.OnStepActionEndH\x00\x12\x38\n\x0c\x66inal_answer\x18\x07 \x01(\x0b\x32 .octopus_agent_proto.FinalAnswerH\x00\x12\x18\n\x0e\x63onsole_stdout\x18\x08 \x01(\tH\x00\x12\x18\n\x0e\x63onsole_stderr\x18\t \x01(\tH\x00\x12\x13\n\terror_msg\x18\n \x01(\tH\x00\x12<\n\x0etyping_content\x18\x0b \x01(\x0b\x32\".octopus_agent_proto.TypingContentH\x00\"\x99\x02\n\x0cResponseType\x12\x15\n\x11OnStepActionStart\x10\x00\x12\x1c\n\x18OnStepActionStreamStdout\x10\x01\x12\x1c\n\x18OnStepActionStreamStderr\x10\x02\x12\x13\n\x0fOnStepActionEnd\x10\x03\x12\x11\n\rOnFinalAnswer\x10\x04\x12\x13\n\x0fOnModelTypeText\x10\x05\x12\x13\n\x0fOnModelTypeCode\x10\x06\x12\x16\n\x12OnModelOutputError\x10\x07\x12\x1b\n\x17OnInputTokenLimitExceed\x10\x08\x12\x1c\n\x18OnOutputTokenLimitExceed\x10\t\x12\x11\n\rOnSystemError\x10\nB\x06\n\x04\x62ody\"1\n\x10\x41\x64\x64KernelRequest\x12\x10\n\x08\x65ndpoint\x18\x01 \x01(\t\x12\x0b\n\x03key\x18\x03 \x01(\t\".\n\x11\x41\x64\x64KernelResponse\x12\x0c\n\x04\x63ode\x18\x01 \x01(\x05\x12\x0b\n\x03msg\x18\x02 \x01(\t\"i\n\x12\x41ssembleAppRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x10\n\x08language\x18\x02 \x01(\t\x12\x0c\n\x04\x63ode\x18\x03 \x01(\t\x12\x17\n\x0fsaved_filenames\x18\x04 \x03(\t\x12\x0c\n\x04\x64\x65sc\x18\x05 \x01(\t\"0\n\x13\x41ssembleAppResponse\x12\x0c\n\x04\x63ode\x18\x01 \x01(\x05\x12\x0b\n\x03msg\x18\x02 \x01(\t\"\x1d\n\rRunAppRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\"F\n\x07\x41ppInfo\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x10\n\x08language\x18\x02 \x01(\t\x12\r\n\x05\x63time\x18\x03 \x01(\x05\x12\x0c\n\x04\x64\x65sc\x18\x04 \x01(\t\"\x12\n\x10QueryAppsRequest\"?\n\x11QueryAppsResponse\x12*\n\x04\x61pps\x18\x01 \x03(\x0b\x32\x1c.octopus_agent_proto.AppInfo\"\r\n\x0bPingRequest\")\n\x0cPongResponse\x12\x0c\n\x04\x63ode\x18\x01 \x01(\x05\x12\x0b\n\x03msg\x18\x02 \x01(\t2\xc6\x03\n\x0b\x41gentServer\x12M\n\x04ping\x12 .octopus_agent_proto.PingRequest\x1a!.octopus_agent_proto.PongResponse\"\x00\x12Q\n\x06upload\x12\x1f.octopus_common_proto.FileChunk\x1a\".octopus_common_proto.FileUploaded\"\x00(\x01\x12V\n\x08\x64ownload\x12%.octopus_common_proto.DownloadRequest\x1a\x1f.octopus_common_proto.FileChunk\"\x00\x30\x01\x12^\n\x0cprocess_task\x12\'.octopus_agent_proto.ProcessTaskRequest\x1a!.octopus_agent_proto.TaskResponse\"\x00\x30\x01\x12]\n\nadd_kernel\x12%.octopus_agent_proto.AddKernelRequest\x1a&.octopus_agent_proto.AddKernelResponse\"\x00\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'agent_server_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_PROCESSOPTIONS']._serialized_start=57
  _globals['_PROCESSOPTIONS']._serialized_end=182
  _globals['_PROCESSTASKREQUEST']._serialized_start=185
  _globals['_PROCESSTASKREQUEST']._serialized_end=314
  _globals['_ONSTEPACTIONSTART']._serialized_start=316
  _globals['_ONSTEPACTIONSTART']._serialized_end=364
  _globals['_ONSTEPACTIONEND']._serialized_start=366
  _globals['_ONSTEPACTIONEND']._serialized_end=440
  _globals['_FINALANSWER']._serialized_start=442
  _globals['_FINALANSWER']._serialized_end=471
  _globals['_CONTEXTSTATE']._serialized_start=474
  _globals['_CONTEXTSTATE']._serialized_end=616
  _globals['_TYPINGCONTENT']._serialized_start=618
  _globals['_TYPINGCONTENT']._serialized_end=668
  _globals['_TASKRESPONSE']._serialized_start=671
  _globals['_TASKRESPONSE']._serialized_end=1431
  _globals['_TASKRESPONSE_RESPONSETYPE']._serialized_start=1142
  _globals['_TASKRESPONSE_RESPONSETYPE']._serialized_end=1423
  _globals['_ADDKERNELREQUEST']._serialized_start=1433
  _globals['_ADDKERNELREQUEST']._serialized_end=1482
  _globals['_ADDKERNELRESPONSE']._serialized_start=1484
  _globals['_ADDKERNELRESPONSE']._serialized_end=1530
  _globals['_ASSEMBLEAPPREQUEST']._serialized_start=1532
  _globals['_ASSEMBLEAPPREQUEST']._serialized_end=1637
  _globals['_ASSEMBLEAPPRESPONSE']._serialized_start=1639
  _globals['_ASSEMBLEAPPRESPONSE']._serialized_end=1687
  _globals['_RUNAPPREQUEST']._serialized_start=1689
  _globals['_RUNAPPREQUEST']._serialized_end=1718
  _globals['_APPINFO']._serialized_start=1720
  _globals['_APPINFO']._serialized_end=1790
  _globals['_QUERYAPPSREQUEST']._serialized_start=1792
  _globals['_QUERYAPPSREQUEST']._serialized_end=1810
  _globals['_QUERYAPPSRESPONSE']._serialized_start=1812
  _globals['_QUERYAPPSRESPONSE']._serialized_end=1875
  _globals['_PINGREQUEST']._serialized_start=1877
  _globals['_PINGREQUEST']._serialized_end=1890
  _globals['_PONGRESPONSE']._serialized_start=1892
  _globals['_PONGRESPONSE']._serialized_end=1933
  _globals['_AGENTSERVER']._serialized_start=1936
  _globals['_AGENTSERVER']._serialized_end=2390
# @@protoc_insertion_point(module_scope)



# SPDX-FileCopyrightText: 2023 imotai <jackwang@octogen.dev>
# SPDX-FileContributor: imotai
#
# SPDX-License-Identifier: Elastic-2.0

""" """
from setuptools import setup, find_packages

setup(
    name="og_proto",
    version="0.5.1",
    description="Open source code interpreter agent for LLM",
    author="imotai",
    author_email="codego.me@gmail.com",
    url="https://github.com/dbpunk-labs/octogen",
    long_description= open('README.md').read(),
    long_description_content_type='text/markdown',

    packages=[
        "og_proto",
    ],

    package_dir={
        "og_proto": "src/og_proto",
    },

    package_data={"og_proto": ["*.pyi"]},

    install_requires=[
        "grpc-google-iam-v1>=0.12.0",
        "grpcio-tools>=1.40.0",
    ],

    entry_points={
    },

)
